@@ -1,4 +1,6 @@
 package HTML::Shakan::Role::Filter;
+use strict;
+use warnings;
 use Any::Moose '::Role';
 
 requires 'filter';
