@@ -1,4 +1,6 @@
 package HTML::Shakan::Role::Model;
+use strict;
+use warnings;
 use Any::Moose '::Role';
 
 requires 'create', 'update', 'fill';
